------------
Examples
------------

See the main examples page on Github:

 `https://github.com/pjcigan/multicolorfits/blob/master/examples.md <https://github.com/pjcigan/multicolorfits/blob/master/examples.md>`_


